summaryrefslogtreecommitdiff
path: root/contrib/cirrus/setup_environment.sh
diff options
context:
space:
mode:
authorChris Evich <cevich@redhat.com>2019-02-22 09:33:41 -0500
committerChris Evich <cevich@redhat.com>2019-02-22 12:07:36 -0500
commit69c91e044a41455b9d089767f4094c8f992faa7e (patch)
tree01e2e4c937a51c2eaf62bc712d358c3925df3876 /contrib/cirrus/setup_environment.sh
parent7184efe93980f2e59bed08f0bf9430c8f35f030d (diff)
downloadpodman-69c91e044a41455b9d089767f4094c8f992faa7e.tar.gz
podman-69c91e044a41455b9d089767f4094c8f992faa7e.tar.bz2
podman-69c91e044a41455b9d089767f4094c8f992faa7e.zip
Cirrus: Install Go 1.11 on Ubuntu VMs
There is no native package for this, so the packaged version must also be installed, otherwise all the support/dependencies would be removed also (like go-md2man). Fix this by installing from the google released tarball, into /usr/local/go and set $GOROOT to point there. Also, include a small fix for hack/get_ci_vm.sh not installing testing dependencies because of an old assumption. ***CIRRUS: REBUILD IMAGES*** Signed-off-by: Chris Evich <cevich@redhat.com>
Diffstat (limited to 'contrib/cirrus/setup_environment.sh')
-rwxr-xr-xcontrib/cirrus/setup_environment.sh5
1 files changed, 3 insertions, 2 deletions
diff --git a/contrib/cirrus/setup_environment.sh b/contrib/cirrus/setup_environment.sh
index 838f3c3f3..77c20d9bd 100755
--- a/contrib/cirrus/setup_environment.sh
+++ b/contrib/cirrus/setup_environment.sh
@@ -79,8 +79,9 @@ then
cd "${GOSRC}/"
source "$SCRIPT_BASE/lib.sh"
- # Only testing-VMs need deps installed
- [[ -n "$PACKER_BUILDS" ]] || install_testing_dependencies # must exist in $GOPATH
+ # Only testing-VMs need deps installed, not image-builder VM
+ echo "$CIRRUS_TASK_NAME" | grep -q 'image' || \
+ install_testing_dependencies # must exist in $GOPATH
fi
record_timestamp "env. setup end"